@@ -5,7 +5,7 @@
 from syst3m.classes import utils, console, objects, browser, cache
 from syst3m.classes.system import User, Group
 from syst3m.classes.color import color, symbol
-from syst3m.classes.defaults import defaults, kill, processes, safe_imports
+from syst3m.classes.defaults import defaults, kill, processes
 from syst3m.classes.env import env
 from syst3m.classes.disks import disks
 #from syst3m.classes.screen import screen
