@@ -2,7 +2,28 @@
 # -*- coding: utf-8 -*-
 
 # defaults.
-import os,sys,json
+import os,sys,json,pathlib,platform
+def __get_argument__(argument, required=True, index=1, empty=None):
+
+	# check presence.
+	if argument not in sys.argv:
+		if required:
+			raise ValueError(f"Define parameter [{argument}].")
+		else: return empty
+
+	# retrieve.
+	y = 0
+	for x in sys.argv:
+		try:
+			if x == argument: return sys.argv[y+index]
+		except IndexError:
+			if required:
+				raise ValueError(f"Define parameter [{argument}].")
+			else: return empty
+		y += 1
+
+	# should not happen.
+	return empty
 def __get_operating_system__():
 	os = platform.system().lower()
 	if os in ["darwin"]: return "osx"
@@ -32,7 +53,7 @@ def __check_alias__(
 	# the source path.
 	executable=None,
 ):
-	present = "--create-alias" in sys.argv and cl1.get_argument("--create-alias") == alias
+	present = "--create-alias" in sys.argv and __get_argument__("--create-alias") == alias
 	base = f"/usr/local/bin"
 	if not os.path.exists(base):
 		base = f"/usr/bin/"
@@ -53,7 +74,7 @@ def __check_alias__(
 			print(f'Successfully created alias: {alias}.')
 			print(f"Check out the docs for more info $: {alias} -h")
 	if present:
-		quit()
+		sys.exit(0)
 
 # source.
 ALIAS = "syst3m"
@@ -62,8 +83,23 @@ SOURCE_PATH= __get_source_path__(__file__, back=3)
 OS = __get_operating_system__()
 
 # imports.
-def imports():
-	
+try: 
+
+	# pip imports.
+	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
+
+	# inc imports.
+	import cl1
+	from fil3s import Files, Formats
+	from r3sponse import r3sponse
+
+# download.
+except ImportError as e:
+	if os.path.exists("/usr/bin/pip3"): 
+		os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
+	else:
+		os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
+
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
 
@@ -72,16 +108,6 @@ def imports():
 	from fil3s import Files, Formats
 	from r3sponse import r3sponse
 
-	#
-def safe_imports(reattempt=True, imports=imports):
-	try: imports()
-	except ImportError as e:
-		if not reattempt: raise ImportError(e)
-		if os.path.exists("/usr/bin/pip3"): 
-			os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
-		else:
-			os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
-safe_imports()
 
 # universal variables.
 USER = os.environ.get("USER")
