@@ -6,18 +6,6 @@ from syst3m.classes.config import *
 from syst3m.classes import utils, console
 import platform 
 
-# safe imports.
-def imports():
-	a=1
-def safe_imports(reattempt=True, imports=imports):
-	try: imports()
-	except ImportError as e:
-		if not reattempt: raise ImportError(e)
-		if os.path.exists("/usr/bin/pip3"): 
-			os.system(f"/usr/bin/pip3 install -r {SOURCE_PATH}/requirements/requirements.txt --user {OWNER}")
-		else:
-			os.system(f"pip3 install -r {SOURCE_PATH}/requirements/requirements.txt")
-
 # kill pid.
 def kill(
 	# the process id.
